package com.sun.media.sound;

import java.io.IOException;
import javax.sound.sampled.AudioInputStream;
import javax.sound.sampled.SourceDataLine;

public final class SoftAudioPusher implements Runnable
{
    private volatile boolean active;
    private SourceDataLine sourceDataLine;
    private Thread audiothread;
    private final AudioInputStream ais;
    private final byte[] buffer;
    
    public SoftAudioPusher(SourceDataLine sourceDataLine, AudioInputStream ais, int n) {
        this.active = false;
        this.sourceDataLine = null;
        this.ais = ais;
        this.buffer = new byte[n];
        this.sourceDataLine = sourceDataLine;
    }
    
    public synchronized void start() {
        if (this.active) {
            return;
        }
        this.active = true;
        (this.audiothread = new Thread(this)).setDaemon(true);
        this.audiothread.setPriority(10);
        this.audiothread.start();
        return;
    }
    
    public synchronized void stop() {
        if (!this.active) {
            return;
        }
        this.active = false;
        try {
            this.audiothread.join();
        }
        catch (InterruptedException ex) {}
        return;
    }
    
    @Override
    public void run() {
        byte[] buffer = this.buffer;
        AudioInputStream ais = this.ais;
        SourceDataLine sourceDataLine = this.sourceDataLine;
        try {
            while (this.active) {
                int read = ais.read(buffer);
                if (read < 0) {
                    break;
                }
                sourceDataLine.write(buffer, 0, read);
            }
        }
        catch (IOException ex) {
            this.active = false;
        }
    }
}
